# ntfy-synologychat

Synology Chat backend for ntfy.

## Usage

``` yaml
ntfy_synologychat:
    webhook_url: ...
    verify: false
```

Required parameters:

- `webhook_url` - string, a incoming webhook url generated by Synology Chat.

Optional parameters:

- `verify` - bool, whether verify https connection.
